==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/Semver.java <==
package io.github.cdklabs.projen;

/**
 * @deprecated This class will be removed in upcoming releases. if you wish to
 * specify semver requirements in `deps`, `devDeps`, etc, specify them like so
 * `express@^2.1`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.439Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
@Deprecated
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.Semver")
public class Semver extends software.amazon.jsii.JsiiObject {

    protected Semver(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Semver(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * (deprecated) Accept any minor version.
     * <p>
     * <blockquote>
     * <p>
     * = version
     * &lt; next major version
     * <p>
     * </blockquote>
     * <p>
     * @param version This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public static @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Semver caret(final @org.jetbrains.annotations.NotNull java.lang.String version) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(io.github.cdklabs.projen.Semver.class, "caret", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Semver.class), new Object[] { java.util.Objects.requireNonNull(version, "version is required") });
    }

    /**
     * (deprecated) Latest version.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public static @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Semver latest() {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(io.github.cdklabs.projen.Semver.class, "latest", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Semver.class));
    }

    /**
     * @param spec This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public static @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Semver of(final @org.jetbrains.annotations.NotNull java.lang.String spec) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(io.github.cdklabs.projen.Semver.class, "of", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Semver.class), new Object[] { java.util.Objects.requireNonNull(spec, "spec is required") });
    }

    /**
     * (deprecated) Accept only an exact version.
     * <p>
     * @param version This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public static @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Semver pinned(final @org.jetbrains.annotations.NotNull java.lang.String version) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(io.github.cdklabs.projen.Semver.class, "pinned", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Semver.class), new Object[] { java.util.Objects.requireNonNull(version, "version is required") });
    }

    /**
     * (deprecated) Accept patches.
     * <p>
     * <blockquote>
     * <p>
     * = version
     * &lt; next minor version
     * <p>
     * </blockquote>
     * <p>
     * @param version This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public static @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Semver tilde(final @org.jetbrains.annotations.NotNull java.lang.String version) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(io.github.cdklabs.projen.Semver.class, "tilde", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Semver.class), new Object[] { java.util.Objects.requireNonNull(version, "version is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public @org.jetbrains.annotations.NotNull java.lang.String getSpec() {
        return software.amazon.jsii.Kernel.get(this, "spec", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public @org.jetbrains.annotations.Nullable java.lang.String getMode() {
        return software.amazon.jsii.Kernel.get(this, "mode", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public @org.jetbrains.annotations.Nullable java.lang.String getVersion() {
        return software.amazon.jsii.Kernel.get(this, "version", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/Semver.java <==
package io.github.cdklabs.projen;

/**
 * @deprecated This class will be removed in upcoming releases. if you wish to
 * specify semver requirements in <code>deps</code>, <code>devDeps</code>, etc, specify them like so
 * <code>express&#64;^2.1</code>.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.149Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
@Deprecated
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.Semver")
public class Semver extends software.amazon.jsii.JsiiObject {

    protected Semver(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Semver(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * (deprecated) Accept any minor version.
     * <p>
     * <blockquote>
     * <p>
     * = version
     * &lt; next major version
     * <p>
     * </blockquote>
     * <p>
     * @param version This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public static @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Semver caret(final @org.jetbrains.annotations.NotNull java.lang.String version) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(io.github.cdklabs.projen.Semver.class, "caret", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Semver.class), new Object[] { java.util.Objects.requireNonNull(version, "version is required") });
    }

    /**
     * (deprecated) Latest version.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public static @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Semver latest() {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(io.github.cdklabs.projen.Semver.class, "latest", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Semver.class));
    }

    /**
     * @param spec This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public static @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Semver of(final @org.jetbrains.annotations.NotNull java.lang.String spec) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(io.github.cdklabs.projen.Semver.class, "of", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Semver.class), new Object[] { java.util.Objects.requireNonNull(spec, "spec is required") });
    }

    /**
     * (deprecated) Accept only an exact version.
     * <p>
     * @param version This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public static @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Semver pinned(final @org.jetbrains.annotations.NotNull java.lang.String version) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(io.github.cdklabs.projen.Semver.class, "pinned", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Semver.class), new Object[] { java.util.Objects.requireNonNull(version, "version is required") });
    }

    /**
     * (deprecated) Accept patches.
     * <p>
     * <blockquote>
     * <p>
     * = version
     * &lt; next minor version
     * <p>
     * </blockquote>
     * <p>
     * @param version This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public static @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Semver tilde(final @org.jetbrains.annotations.NotNull java.lang.String version) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(io.github.cdklabs.projen.Semver.class, "tilde", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Semver.class), new Object[] { java.util.Objects.requireNonNull(version, "version is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public @org.jetbrains.annotations.NotNull java.lang.String getSpec() {
        return software.amazon.jsii.Kernel.get(this, "spec", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public @org.jetbrains.annotations.Nullable java.lang.String getMode() {
        return software.amazon.jsii.Kernel.get(this, "mode", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public @org.jetbrains.annotations.Nullable java.lang.String getVersion() {
        return software.amazon.jsii.Kernel.get(this, "version", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }
}
